@@ -1,8 +1,8 @@
 use std::{env, path::PathBuf};
 
 use clap::Parser;
+use cookbook::{gen_docs, run, Config};
 use env_logger::Env;
-use server::{gen_docs, run, Config};
 
 #[derive(Parser, Debug)]
 struct Args {
